@@ -3,7 +3,7 @@ from typing_extensions import Annotated
 
 
 def main(
-    name: Annotated[str, typer.Argument(envvar=["AWESOME_NAME", "GOD_NAME"])] = "World"
+    name: Annotated[str, typer.Argument(envvar=["AWESOME_NAME", "GOD_NAME"])] = "World",
 ):
     print(f"Hello Mr. {name}")
 
