@@ -5,12 +5,12 @@ app = typer.Typer()
 
 @app.command()
 def create():
-    typer.echo("Creating user: Hiro Hamada")
+    print("Creating user: Hiro Hamada")
 
 
 @app.command()
 def delete():
-    typer.echo("Deleting user: Hiro Hamada")
+    print("Deleting user: Hiro Hamada")
 
 
 if __name__ == "__main__":
