@@ -5,7 +5,7 @@ app = typer.Typer()
 
 @app.command()
 def create():
-    typer.echo("Creating user: Hiro Hamada")
+    print("Creating user: Hiro Hamada")
 
 
 @app.callback()
