@@ -2,7 +2,7 @@ import typer
 
 
 def main(name: str, lastname: str):
-    typer.echo(f"Hello {name} {lastname}")
+    print(f"Hello {name} {lastname}")
 
 
 if __name__ == "__main__":
