@@ -4,7 +4,7 @@ import typer
 
 
 def main(number: List[float] = typer.Option([])):
-    typer.echo(f"The sum is {sum(number)}")
+    print(f"The sum is {sum(number)}")
 
 
 if __name__ == "__main__":
