@@ -6,11 +6,11 @@ import typer
 def main(user: Tuple[str, int, bool] = typer.Option((None, None, None))):
     username, coins, is_wizard = user
     if not username:
-        typer.echo("No user provided")
+        print("No user provided")
         raise typer.Abort()
-    typer.echo(f"The username {username} has {coins} coins")
+    print(f"The username {username} has {coins} coins")
     if is_wizard:
-        typer.echo("And this user is a wizard!")
+        print("And this user is a wizard!")
 
 
 if __name__ == "__main__":
