@@ -3,9 +3,9 @@ import typer
 
 def main(in_prod: bool = typer.Option(True, " /--demo", " /-d")):
     if in_prod:
-        typer.echo("Running in production")
+        print("Running in production")
     else:
-        typer.echo("Running demo")
+        print("Running demo")
 
 
 if __name__ == "__main__":
