@@ -15,7 +15,7 @@ def parse_custom_class(value: str):
 
 def main(
     custom_arg: CustomClass = typer.Argument(parser=parse_custom_class),
-    custom_opt: CustomClass = typer.Option("Y", parser=parse_custom_class),
+    custom_opt: CustomClass = typer.Option("Foo", parser=parse_custom_class),
 ):
     print(f"custom_arg is {custom_arg}")
     print(f"--custom-opt is {custom_opt}")
