@@ -3,7 +3,7 @@ import typer
 
 def main(config: typer.FileText = typer.Option(...)):
     for line in config:
-        typer.echo(f"Config line: {line}")
+        print(f"Config line: {line}")
 
 
 if __name__ == "__main__":
