@@ -4,9 +4,9 @@ import typer
 def main():
     delete = typer.confirm("Are you sure you want to delete it?")
     if not delete:
-        typer.echo("Not deleting")
+        print("Not deleting")
         raise typer.Abort()
-    typer.echo("Deleting it!")
+    print("Deleting it!")
 
 
 if __name__ == "__main__":
