@@ -3,7 +3,7 @@ import typer
 
 def main():
     delete = typer.confirm("Are you sure you want to delete it?", abort=True)
-    typer.echo("Deleting it!")
+    print("Deleting it!")
 
 
 if __name__ == "__main__":
