@@ -4,7 +4,7 @@ app = typer.Typer()
 
 
 def users_callback():
-    typer.echo("Running a users command")
+    print("Running a users command")
 
 
 users_app = typer.Typer(callback=users_callback)
@@ -13,7 +13,7 @@ app.add_typer(users_app, name="users")
 
 @users_app.command()
 def create(name: str):
-    typer.echo(f"Creating user: {name}")
+    print(f"Creating user: {name}")
 
 
 if __name__ == "__main__":
