@@ -4,7 +4,7 @@ app = typer.Typer()
 
 
 def default_callback():
-    typer.echo("Running a users command")
+    print("Running a users command")
 
 
 users_app = typer.Typer(callback=default_callback)
@@ -13,12 +13,12 @@ app.add_typer(users_app, name="users")
 
 @users_app.callback()
 def user_callback():
-    typer.echo("Callback override, running users command")
+    print("Callback override, running users command")
 
 
 @users_app.command()
 def create(name: str):
-    typer.echo(f"Creating user: {name}")
+    print(f"Creating user: {name}")
 
 
 if __name__ == "__main__":
