@@ -8,7 +8,7 @@ app.add_typer(users_app, name="users", help="Manage users in the app.")
 
 @users_app.command()
 def create(name: str):
-    typer.echo(f"Creating user: {name}")
+    print(f"Creating user: {name}")
 
 
 if __name__ == "__main__":
