@@ -5,7 +5,7 @@ app = typer.Typer()
 
 @app.command()
 def main(name: str, email: str = typer.Option(..., prompt=True)):
-    typer.echo(f"Hello {name}, your email is: {email}")
+    print(f"Hello {name}, your email is: {email}")
 
 
 if __name__ == "__main__":
