@@ -7,7 +7,7 @@ import click
 def hello(count, name):
     """Simple program that greets NAME for a total of COUNT times."""
     for x in range(count):
-        click.echo("Hello %s!" % name)
+        click.echo(f"Hello {name}!")
 
 
 if __name__ == "__main__":
