@@ -1,3 +1,6 @@
+import sys
+from pathlib import Path
+
 import typer
 from typer.testing import CliRunner
 from typing_extensions import Annotated
@@ -76,3 +79,22 @@ def test_annotated_option_with_argname_doesnt_mutate_multiple_calls():
     result = runner.invoke(app, ["--force"])
     assert result.exit_code == 0, result.output
     assert "Forcing operation" in result.output
+
+
+def test_annotated_custom_path():
+    app = typer.Typer()
+
+    class CustomPath(Path):
+        # Subclassing Path was not fully supported before 3.12
+        # https://docs.python.org/3.12/whatsnew/3.12.html
+        if sys.version_info < (3, 12):
+            _flavour = type(Path())._flavour
+
+    @app.command()
+    def custom_parser(
+        my_path: Annotated[CustomPath, typer.Argument(parser=CustomPath)],
+    ):
+        assert isinstance(my_path, CustomPath)
+
+    result = runner.invoke(app, "/some/quirky/path/implementation")
+    assert result.exit_code == 0
