@@ -12,13 +12,19 @@ runner = CliRunner()
 
 def test_no_arg():
     result = runner.invoke(app)
-    assert result.exit_code == 0
     assert "[OPTIONS] COMMAND [ARGS]..." in result.output
     assert "Commands" in result.output
     assert "create" in result.output
     assert "delete" in result.output
 
 
+def test_no_additional_output():
+    """Ensure that no additional output was generated (cf. PR #1262)"""
+    result = runner.invoke(app)
+    assert result.output.count("Usage") == 1
+    assert "Error" not in result.output
+
+
 def test_create():
     result = runner.invoke(app, ["create"])
     assert result.exit_code == 0
