@@ -14,8 +14,7 @@ def test_rich_pretty_exceptions_disable():
     file_path = Path(mod.__file__)
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", str(file_path)],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={**os.environ, "_TYPER_STANDARD_TRACEBACK": ""},
     )
@@ -23,18 +22,13 @@ def test_rich_pretty_exceptions_disable():
 
     assert "app()" in result.stderr
     assert "print(name + 3)" in result.stderr
-    # TODO: when deprecating Python 3.6, remove second option
-    assert (
-        'TypeError: can only concatenate str (not "int") to str' in result.stderr
-        or "TypeError: must be str, not int" in result.stderr
-    )
+    assert 'TypeError: can only concatenate str (not "int") to str' in result.stderr
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
