@@ -23,12 +23,7 @@ def test_prompt_not_equal():
         app, input="Old Project\nNew Spice\nOld Project\nOld Project\n"
     )
     assert result.exit_code == 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Error: The two entered values do not match" in result.output
-        or "Error: the two entered values do not match" in result.output
-    )
+    assert "Error: The two entered values do not match" in result.output
     assert "Deleting project Old Project" in result.output
 
 
@@ -50,8 +45,7 @@ def test_help():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
