@@ -26,10 +26,17 @@ def test_main():
     assert "Training neural network of type: conv" in result.output
 
 
+def test_main_default():
+    result = runner.invoke(app)
+    assert result.exit_code == 0
+    assert "Training neural network of type: simple" in result.output
+
+
 def test_invalid_case():
     result = runner.invoke(app, ["--network", "CONV"])
     assert result.exit_code != 0
-    assert "Invalid value for '--network': 'CONV' is not one of" in result.output
+    assert "Invalid value for '--network'" in result.output
+    assert "'CONV' is not one of" in result.output
     assert "simple" in result.output
     assert "conv" in result.output
     assert "lstm" in result.output
@@ -38,7 +45,8 @@ def test_invalid_case():
 def test_invalid_other():
     result = runner.invoke(app, ["--network", "capsule"])
     assert result.exit_code != 0
-    assert "Invalid value for '--network': 'capsule' is not one of" in result.output
+    assert "Invalid value for '--network'" in result.output
+    assert "'capsule' is not one of" in result.output
     assert "simple" in result.output
     assert "conv" in result.output
     assert "lstm" in result.output
