@@ -15,12 +15,8 @@ app.command()(mod.main)
 def test_invalid_id():
     result = runner.invoke(app, ["1002"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
     assert (
         "Invalid value for 'ID': 1002 is not in the range 0<=x<=1000" in result.output
-        or "Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
-        in result.output
     )
 
 
@@ -35,8 +31,7 @@ def test_clamped():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
