@@ -22,21 +22,16 @@ def test_main():
 def test_invalid_uuid():
     result = runner.invoke(app, ["7479706572-72756c6573"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
     assert (
         "Invalid value for 'USER_ID': '7479706572-72756c6573' is not a valid UUID"
         in result.output
-        or "Invalid value for 'USER_ID': 7479706572-72756c6573 is not a valid UUID value"
-        in result.output
     )
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
