@@ -1,4 +1,5 @@
 import subprocess
+import sys
 
 from typer.testing import CliRunner
 
@@ -25,9 +26,8 @@ def test_for_coverage():
 
 def test_script():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
