@@ -14,18 +14,18 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "Commands" in result.output
-    assert "call-users" in result.output
+    assert "users" in result.output
     assert "Help from callback for users." in result.output
 
 
 def test_command_help():
-    result = runner.invoke(app, ["call-users", "--help"])
+    result = runner.invoke(app, ["users", "--help"])
     assert result.exit_code == 0
     assert "Help from callback for users." in result.output
 
 
 def test_command():
-    result = runner.invoke(app, ["call-users", "create", "Camila"])
+    result = runner.invoke(app, ["users", "create", "Camila"])
     assert result.exit_code == 0
     assert "Creating user: Camila" in result.output
 
