@@ -1,6 +1,7 @@
 import subprocess
 import sys
 
+import pytest
 import typer
 import typer.core
 from typer.testing import CliRunner
@@ -32,15 +33,13 @@ def test_root_no_standalone():
     assert result.exit_code == 1
 
 
-def test_root_no_rich():
+def test_root_no_rich(monkeypatch: pytest.MonkeyPatch):
     # Mainly for coverage
-    rich = typer.core.rich
-    typer.core.rich = None
+    monkeypatch.setattr(typer.core, "HAS_RICH", False)
     result = runner.invoke(app, ["root"])
     assert result.exit_code == 1
     assert "The root user is reserved" in result.output
     assert "Aborted!" in result.output
-    typer.core.rich = rich
 
 
 def test_script():
